Package: ZIPLDA
Type: Package
Title: Classifying NGS data package
Version: 0.1.0
Date: 2017-12-23
Author: Zhou Yan
Maintainer: Zhou Yan <zhouy1016@szu.edu.cn>
Description: Classifying next-generation sequencing data using a zero-inflated Poisson model.
Imports: PoiClaClu
License: GPL-2
Encoding: UTF-8
LazyData: true
NeedsCompilation: no
Packaged: 2017-12-23 11:17:42 UTC; Administrator
