\name{ZIPDA.cv}
\alias{ZIPDA.cv}
\title{Hello, World!}
\usage{
  ZIPDA.cv(x,y,rhos=NULL,beta=1,nfolds=5,prob0=NULL,
  type=c("mle","deseq","quantile"),folds=NULL,
  transform=TRUE, alpha=NULL, prior=NULL)
}
\description{
  Prints 'Hello, world!'.
}
\keyword{internal}
