\name{ZIPLDA-package}
\alias{ZIPLDA-package}
\docType{package}
\title{
  A approach using a zero-inflated Poisson model to classify next-generation sequencing data.
}
\description{
  The main idea of ZIPLDA
  is that since RNA-seq data with an excess of zeros, then we assumes that the data are from a mixturn of two distributions: one is a point mass at zero, and the other follows a Poisson distribution, and consider a logistic relation between the probability of observing zeros and the mean of the genes and the sequencing depth in the model.

}
\author{
  Yan Zhou

  Maintainer:Yan Zhou <zhouy1016@szu.edu.cn>
}
\references{
  Yan Zhou, Xiang Wan, Baoxue Zhang and Tiejun Tong (2017). Classifying next-generation sequencing data using a zero-inflated Poisson model.
}
\keyword{ package }
\seealso{
  ?ZIPLDA
}
\examples{
  set.seed(1)
dat <- CountDataSet1(n=40,p=50,sdsignal=0.2,K=2,
param=1/0.001,drate=0.2)

prob<-estimatep(dat$x,dat$y,xte=dat$x,beta=1,
type=c("mle","deseq","quantile"), prior=NULL)

prob0<-estimatep(dat$x,dat$y,dat$xte,beta=1,
type=c("mle","deseq","quantile"), prior=NULL)

prob<-t(prob)
prob0<-t(prob0)

zipldacv.out <- ZIPDA.cv(dat$x,dat$y,prob0=prob)

ZIPLDA(dat$x,dat$y,dat$xte,transform=FALSE,
prob0=prob0,rho=zipldacv.out$bestrho)
}

