\name{estimatep}
\alias{estimatep}
\title{Estimation the zero distribution probability}
\description{
  This function is to estimate the zero distribution probability.
}

\usage{
  estimatep(x,y,xte=NULL,beta=1,type=c("mle","deseq","quantile"), prior=NULL)
}

\arguments{
  \item{x}{A matrix or data.frame for training data.
  }
  \item{y}{A vector shows each sample in training set belongs to which class.
  }
  \item{xte}{A matrix or data.frame for test data. If equalls to NULL, testing will be performed on training data set.
  }
  \item{beta}{
  }
  \item{type}{There are three types can choose,
  }
  \item{prior}{Prior probability to calculate zero distribution probability, default is NULL, that is each class has equall prior probability.
  }
}

\value{
  \item{p}{The probability of zero distribution.

  }
}
\seealso{?estimatep()}

\keyword{internal}








