\name{calcNormFactors}
\alias{calcNormFactors}
\title{Hello, World!}
\usage{
  calcNormFactors(dataMatrix, refColumn=1,
                  logratioTrim=.3, sumTrim=0.05,
                  doWeighting=TRUE, Acutoff=-1e10)
}
\description{
  Prints 'Hello, world!'.
}
\keyword{internal}
