\name{estimatep1}
\alias{estimatep1}
\title{Hello, World!}
\usage{
  estimatep1(x,y,xte=NULL,beta=1,type=c("mle","deseq","quantile"), prior=NULL)
}
\description{
  Prints 'Hello, world!'.
}
\keyword{internal}
