\name{.calcFactorWeighted}
\alias{.calcFactorWeighted}
\title{Hello, World!}
\usage{
  .calcFactorWeighted(obs, ref, logratioTrim=.3,
  sumTrim=0.05, doWeighting=TRUE, Acutoff=-1e10)
}
\description{
  Prints 'Hello, world!'.
}
\keyword{internal}
