\name{CountDataSet2}
\alias{CountDataSet2}
\title{Simulation data for multiple classification.}
\description{
  Generation a dataset for multiple classification.
}

\usage{
  CountDataSet2(n, p, K, param, sdsignal, drate)
}

\arguments{
  \item{n}{Total number of samples for all classes.
  }
  \item{p}{The number of features in each samples.
  }
  \item{k}{Number of classes.
  }
  \item{param}{One of parameter for negative binomial distribution, which is the reciprocal of
    phi.
  }
  \item{sdsignal}{One of parameter for normal distribution, which is the standard deviation.
  }
  \item{drate}{The proportion for the differentially expressed genes.
  }
}

\value{An object of class "CountDataSet2" is a list containing at least the following components:

    \item{x}{Simulation training set which is a n by p matrix.
    }
  \item{xte}{Simulation test set which is also a n by p matrix.

  }
  \item{y}{A vector shows each sample in training set belongs to which class.

  }
  \item{yte}{A vector shows each sample in test set belongs to which class.

  }
  \item{truesf}{The true size factor for training set.

  }
  \item{truesfte}{The true size factor for test set.
  }
  \item{dkg}{A k by p matrix that is prepared for calculate the expectation for negative binomial distribution.
  }
}
\seealso{?CountDataSet2()}
\keyword{internal}









