\name{classZIP}
\alias{classZIP}
\title{Hello, World!}
\usage{
  classZIP(x,y,xte=NULL,beta=1,prob=NULL,prob0=NULL,
  type=c("mle","deseq","quantile"), prior=NULL,
  transform=TRUE, alpha=NULL)
}
\description{
  Prints 'Hello, world!'.
}
\keyword{internal}
